==> haskell-geniplate-mirror-0.7.7-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-geniplate-mirror.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 geniplate-mirror
version:              0.7.7
visibility:           public
id:                   geniplate-mirror-0.7.7-I9tTciU1Lbh2gDibGSQjqh
key:                  geniplate-mirror-0.7.7-I9tTciU1Lbh2gDibGSQjqh
license:              BSD-3-Clause
copyright:            2014-2015 Lennart Augustsson
maintainer:
    Dan Rosén <dan.rosen@gu.se>, Liang-Ting Chen <liang.ting.chen.tw@gmail.com>

author:               Lennart Augustsson
stability:            experimental
homepage:             https://github.com/danr/geniplate
synopsis:             Use Template Haskell to generate Uniplate-like functions.
description:
    Use Template Haskell to generate Uniplate-like functions.

    This is a maintained mirror of the
    <http://hackage.haskell.org/package/geniplate geniplate> package,
    written by Lennart Augustsson.

category:             Generics
abi:                  4841579feaad50a84fec4ac23bc731fb
exposed:              True
exposed-modules:      Data.Generics.Geniplate
import-dirs:          /usr/lib/ghc-8.8.3/site-local/geniplate-mirror-0.7.7
library-dirs:         /usr/lib/ghc-8.8.3/site-local/geniplate-mirror-0.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/geniplate-mirror-0.7.7
hs-libraries:         HSgeniplate-mirror-0.7.7-I9tTciU1Lbh2gDibGSQjqh
depends:              base-4.13.0.0 mtl-2.2.2 template-haskell-2.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-geniplate-mirror/html/geniplate-mirror.haddock

haddock-html:         /usr/share/doc/haskell-geniplate-mirror/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-geniplate-mirror-0.7.7-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-geniplate-mirror.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 geniplate-mirror
version:              0.7.7
visibility:           public
id:                   geniplate-mirror-0.7.7-HRbG7QMFaAM14lr8R2TNY0
key:                  geniplate-mirror-0.7.7-HRbG7QMFaAM14lr8R2TNY0
license:              BSD-3-Clause
copyright:            2014-2015 Lennart Augustsson
maintainer:
    Dan Rosén <dan.rosen@gu.se>, Liang-Ting Chen <liang.ting.chen.tw@gmail.com>

author:               Lennart Augustsson
stability:            experimental
homepage:             https://github.com/danr/geniplate
synopsis:             Use Template Haskell to generate Uniplate-like functions.
description:
    Use Template Haskell to generate Uniplate-like functions.

    This is a maintained mirror of the
    <http://hackage.haskell.org/package/geniplate geniplate> package,
    written by Lennart Augustsson.

category:             Generics
abi:                  bf060215a37ff05f1dc483678db318cf
exposed:              True
exposed-modules:      Data.Generics.Geniplate
import-dirs:          /usr/lib/ghc-8.10.1/site-local/geniplate-mirror-0.7.7
library-dirs:         /usr/lib/ghc-8.10.1/site-local/geniplate-mirror-0.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/geniplate-mirror-0.7.7
hs-libraries:         HSgeniplate-mirror-0.7.7-HRbG7QMFaAM14lr8R2TNY0
depends:              base-4.14.0.0 mtl-2.2.2 template-haskell-2.16.0.0
haddock-interfaces:
    /usr/share/doc/haskell-geniplate-mirror/html/geniplate-mirror.haddock

haddock-html:         /usr/share/doc/haskell-geniplate-mirror/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
